@@ -48,13 +48,20 @@
 #pod         …
 #pod     };
 #pod
+#pod     sub another_method {
+#pod         my $self = shift( @_ );
+#pod         …
+#pod         $self->fill_in_file( $file );
+#pod         …
+#pod     };
+#pod
 #pod     __PACKAGE__->meta->make_immutable;
 #pod     1;
 #pod
 #pod =head1 DESCRIPTION
 #pod
-#pod The role provides consuming plugin with C<fill_in_string> method and bunch of accompanying
-#pod attributes and F<dist.ini> options.
+#pod The role provides consuming plugin with C<fill_in_string> and C<fill_in_file> methods and bunch of
+#pod accompanying attributes and F<dist.ini> options.
 #pod
 #pod =cut
 
@@ -64,12 +71,13 @@ use Moose::Role;
 use namespace::autoclean;
 
 # ABSTRACT: Have text templating capabilities in your Dist::Zilla plugin
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
 
 use Text::Template qw{};
 use Carp qw{ croak };
+use List::Util qw{ min max };
 
 # --------------------------------------------------------------------------------------------------
 
@@ -78,7 +86,7 @@ use Carp qw{ croak };
 #pod Pair of open and closing delimiters the code fragments surrounded by.
 #pod
 #pod Attribute introduces F<dist.ini> option with the same name. Option value will be split on
-#pod whitespaces (and result should ) to initialize the attribute.
+#pod whitespaces (and result should be two words) to initialize the attribute.
 #pod
 #pod C<Str|ArrayRef[Str]>, read-only. Default value is C<[ '{{', '}}' ]>.
 #pod
@@ -117,7 +125,7 @@ has delimiters => (
 #pod
 #pod Attribute introduces F<dist.ini> option with the same name.
 #pod
-#pod Str, read-only, optional.
+#pod C<Str>, read-only, optional.
 #pod
 #pod See C<PACKAGE> option of L<Text::Template/"fill_in">.
 #pod
@@ -137,7 +145,7 @@ has package => (
 #pod
 #pod Attribute introduces F<dist.ini> multi-value option with the same name.
 #pod
-#pod ArrayRef[Str], read-only, auto dereferenced. Default value is empty array. Another default value
+#pod C<ArrayRef[Str]>, read-only, auto dereferenced. Default value is empty array. Another default value
 #pod may be specified by defining C<_build_prepend> method.
 #pod
 #pod See C<PREPEND> option of L<Text::Template/"fill_in">.
@@ -162,7 +170,7 @@ sub _build_prepend {
 #pod Callback to execute if a code fragment dies. Default callback formats detailed error message and
 #pod log it by calling C<log_error>.
 #pod
-#pod CodeRef, read-only, not an init argument. Default callback may be overridden by defining
+#pod C<CodeRef>, read-only, not an init argument. Default callback may be overridden by defining
 #pod C<_build_broken> method.
 #pod
 #pod See C<BROKEN> option of L<Text::Template/"fill_in">.
@@ -176,27 +184,66 @@ has broken => (
     init_arg    => undef,
 );
 
+#   Claculate range of lines to show. $line is a lineno of focus line, $ctx is number of context
+#   lines to show above and below the focus line, $min and $max defined full range. It is usually
+#   1 and number of lines in the text. Note: linunumbers are one-based.
+sub __range($$$$) {
+    my ( $line, $ctx, $min, $max ) = @_;
+    if ( $line > 0 ) {
+        my $first = max( $line - $ctx, $min );  # First line to show.
+        my $last  = min( $line + $ctx, $max );  # Last line to show.
+        if ( $first - $min < $ctx ) {   # If number of skipped lines at top less than context,
+            $first = $min;              # do not skip lines.
+        };
+        if ( $max - $last < $ctx ) {    # If number of skipped lines at botton less than context,
+            $last = $max;               #  do not skip lines.
+        };
+        return ( $first, $last );
+    } else {
+        return ( 0, -1 );
+    };
+};
+
 sub _build_broken {
     my ( $self ) = @_;
     return sub {
-        my %args = @_;
-        my $error    = $args{ error  }; # Error message.
-        my $bline    = $args{ lineno }; # Template line where the problem code fragment begins.
-        my $eline    = $error =~ m{ at template line (\d+)} ? $1 : 0;
-            #   ^Template line where the problem occurs.
-        my @template = split( "\n", $args{ arg } );
-            #   ^Template text.
+        my %args  = @_;
+        my $error = $args{ error };     # Error message.
+        my $tfile = $self->tt_filename; # Template filename.
+        my $tline = $args{ lineno };    # Template line where the problem code fragment begins.
+        my $eline = 0;                                      # Line where the problem occurs,
+        if ( $error =~ m{ at \Q$tfile\E line (\d+)} ) {     # if the problem occurs in template.
+            $eline = $1;
+        };
+        my @template = split( "\n", $self->tt_template );   # Template text.
         chomp( $error );
         $self->log_error( $error );
-        $self->log_error( "Problem code fragment begins at template line $bline." );
-        $self->log_error( "Template text:" );
+        $self->log_error( "Problem code fragment begins at $self->{ tt_filename } line $tline." );
+        $self->log_error( "$tfile:" );
         #   TODO: Chop too long lines.
-        #   TODO: Do not show too big templates, show only problem lines.
-        my $format = '%s %0' . length( @template + 0 ) . 'd: %s';
-        my $n = 0;
-        for my $line ( @template ) {
-            ++ $n;
-            $self->log_error( [ $format, ( $n == $eline ? '>>>' : '   ' ), $n, $line ] );
+        my $ctx  = 2;                       # Context (number of lines to show above and below).
+        my $w    = length( 0 + @template ); # Width of linenumber column.
+        my $text = '    %0' . $w . 'd: %s'; # Template text line format.
+        my $note = '    ' . ( ' ' x $w ) . '  ^^^ %s ^^^';              # Notice line format.
+        my $skip = '    ' . ( ' ' x $w ) . '  ...skipped %d lines...';  # "Skipped" notice format.
+        my ( $t0, $t1 ) = __range( $tline, $ctx,       1, 0 + @template );
+        my ( $e0, $e1 ) = __range( $eline, $ctx, $t1 + 1, 0 + @template );
+        my $last = 0;       # Number of last shown line.
+        for my $line ( $t0 .. $t1, $e0 .. $e1 ) {
+            if ( $line != $last + 1 ) {
+                $self->log_error( [ $skip, $line - $last - 1 ] );
+            };
+            $self->log_error( [ $text, $line, $template[ $line - 1 ] ] );
+            if ( $line == $tline ) {
+                $self->log_error( [ $note, 'Code fragment begins in line above' ] );
+            };
+            if ( $line == $eline ) {
+                $self->log_error( [ $note, 'Code fragment died in line above' ] );
+            };
+            $last = $line;
+        };
+        if ( $last < @template ) {
+            $self->log_error( [ $skip, @template - $last ] );
         };
         # TODO: Do we need $self->abort() here?
     };
@@ -204,6 +251,41 @@ sub _build_broken {
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =attr tt_filename
+#pod
+#pod Name of file being processed, or "template" if no filename was specified (e. g. when processing a
+#pod string and C<filename> option was not specified). Available only during template processing (e. g.
+#pod may be used in a C<broken> subroutine).
+#pod
+#pod C<Str>, read-only, not an init arg.
+#pod
+#pod =cut
+
+has tt_filename => (
+    is          => 'ro',
+    isa         => 'Str',
+    init_arg    => undef,
+);
+
+# --------------------------------------------------------------------------------------------------
+
+#pod =attr tt_template
+#pod
+#pod Template being processed. Available only during template processing (e. g. may be used in a
+#pod C<broken> subroutine).
+#pod
+#pod C<Str>, read-only, not an init arg.
+#pod
+#pod =cut
+
+has tt_template => (
+    is          => 'ro',
+    isa         => 'Str',
+    init_arg    => undef,
+);
+
+# --------------------------------------------------------------------------------------------------
+
 #pod =method mvp_multivalue_args
 #pod
 #pod The method tells C<Dist::Zilla> that C<prepend> is a multi-value option.
@@ -219,24 +301,27 @@ around mvp_multivalue_args => sub {
 
 #pod =method fill_in_string
 #pod
-#pod     $result = $self->fill_in_string( $template, \%variables, \%extra_args );
-#pod     $result = $self->fill_in_string( $template );
+#pod     $string = '…';
+#pod     $result = $self->fill_in_string( $string, \%variables, \%extra_args );
+#pod     $result = $self->fill_in_string( $string );
 #pod
 #pod The primary method of the role.
 #pod
 #pod The interface is compatible with method of C<TextTemplate> role, so this role can be used as a
-#pod drop-in replacement for C<TextTemplate>. However, methods are implemented slightly differently
-#pod (this method calls C<Text::Template::fill_in_string> function, that one creates C<Text::Template>
-#pod object first, then calls C<fill_in> method on the object), it may cause subtle difference in
-#pod behaviour.
+#pod drop-in replacement for C<TextTemplate>. However, methods are implemented slightly differently, it
+#pod may cause subtle difference in behaviour.
 #pod
 #pod Template variables C<$plugin> and C<$dist> are set by default, if not explicitly defined in
 #pod C<\%variables>.
 #pod
-#pod The method calls C<Text::Template::fill_in_string>, passing to it the C<$template>, C<\%variables>,
-#pod attribute values C<package>, C<prepend>, C<broken>, and finally C<%extra_args>. C<%extra_args> is
-#pod passed in the end intentionally, so caller may override any of parameters specified by the method,
-#pod for example:
+#pod The method creates C<Text::Template> object, enforces C<Text::Template> to respect C<filename>
+#pod argument (see L<FILENAME parameter has no
+#pod effect|https://rt.cpan.org/Ticket/Display.html?id=106093>), then calls C<fill_in> method on the
+#pod object. C<$template>, C<\%variables>, and C<package>, C<prepend>, C<broken> attribute values, and
+#pod finally C<%extra_args> are passed to the C<fill_in>.
+#pod
+#pod C<%extra_args> is passed in the end intentionally, so caller may override any of arguments
+#pod specified by the method, for example:
 #pod
 #pod     $self->fill_in_string( $template, undef, { package => 'MY' } );
 #pod         #   Execute code fragments in package MY regardless of $self->package value.
@@ -255,29 +340,41 @@ sub fill_in_string {
         dist   => \( $self->zilla ),
         $hash ? %$hash : (),
     );
-    my @args = (
+    my %args = (
         hash       => \%hash,
         delimiters => $self->delimiters,
         $self->package ? ( package => $self->package,              ) : (),
         $self->prepend ? ( prepend => join( "\n", $self->prepend ) ) : (),
-        $self->broken  ? (
-            broken      => $self->broken,
-            broken_arg  => $string,
-        ) : (),
+        $self->broken  ? ( broken  => $self->broken                ) : (),
         $args ? %$args : (),
     );
-    my $result;
+    my ( $result, $error );
     {
-        #   TODO: Create an attribute.
-        local $SIG{ __WARN__ } = sub {
-            my ( $msg ) = @_;
-            chomp( $msg );
-            $self->log( $msg );
+        #   Original version of the code simply called `Text::Template::fill_in_string` function.
+        #   However, this trivial approach does not work good because of `Text::Template` bug: it
+        #   ignores `filename` argument, see <https://rt.cpan.org/Ticket/Display.html?id=106093>.
+        #   It seems it will not be fixed soon. The bug can be workarounded by setting
+        #   `Text::Template` object property `FILENAME`. In order to do it, we need access to
+        #   `Text::Template` object, that means we have to create it manually, and then call
+        #   `fill_in` method on it.
+        local $Text::Template::ERROR;
+        my $tt = Text::Template->new( type => 'STRING', source => $string, %args );
+        if ( $tt ) {
+            my $filename = ( Text::Template::_param( 'filename', %args ) or 'template' );
+            local $self->{ tt_filename } = $filename;   # Will be used in `broken`.
+            local $self->{ tt_template } = $string;     # ditto.
+            $tt->{ FILENAME } = $filename;  # Workaround for the bug.
+            local $SIG{ __WARN__ } = sub {  # TODO: Create an attribute?
+                my $msg = "$_[ 0 ]";        # Stringify message, it could be an object.
+                chomp( $msg );
+                $self->log( $msg );
+            };
+            $result = $tt->fill_in( %args );
         };
-        $result = Text::Template::fill_in_string( $string, @args );
+        $error = $Text::Template::ERROR;
     }
     if ( not defined( $result ) ) {
-        $self->log_error( $Text::Template::ERROR );
+        $self->log_error( $error );
     };
     $self->abort_if_error();
     return $result;
@@ -285,6 +382,29 @@ sub fill_in_string {
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =method fill_in_file
+#pod
+#pod     $file = Dist::Zilla::File::OnDisk->new( { … } );
+#pod     $result = $self->fill_in_file( $file, \%variables, \%extra_args );
+#pod     $result = $self->fill_in_file( $file );
+#pod
+#pod Similar to C<fill_in_string>, but the first argument is not a string but a file. File content is
+#pod treated as template, and will be replaced with result of template processing. New file content will
+#pod also be returned.
+#pod
+#pod =cut
+
+sub fill_in_file {
+    my ( $self, $file, $hash, $args ) = @_;
+    my %args = (
+        filename => $file->name,
+        $args ? %$args : (),
+    );
+    return $file->content( $self->fill_in_string( $file->content, $hash, \%args ) );
+};
+
+# --------------------------------------------------------------------------------------------------
+
 1;
 
 # --------------------------------------------------------------------------------------------------
@@ -312,6 +432,54 @@ sub fill_in_string {
 #pod and provide your value, use all-lowercase option name. If you want to provide default which can be
 #pod overridden by the user, use all-caps options name.
 #pod
+#pod =head2 C<filename> option
+#pod
+#pod When C<Text::Template> reads template from a file, it uses the file name in error messages, e. g.:
+#pod
+#pod     Undefined subroutine &foo called at filename.ext line n
+#pod
+#pod where I<filename.ext> is the name of file containing the template. When C<Text::Template> processes
+#pod a string, it uses word "template" instead of file name, e. g.:
+#pod
+#pod     Undefined subroutine &foo called at template line n
+#pod
+#pod The option C<filename> allows the caller to override it:
+#pod
+#pod     $self->fill_in_file( $file, undef, { filename => 'Assa.txt' } );
+#pod
+#pod Error message would look like:
+#pod
+#pod     Undefined subroutine &foo called at Assa.txt line n
+#pod
+#pod It may seem this does not make much sense, but in our case (C<Dist::Zilla> and its plugins)
+#pod C<Text::Template> always processes strings and never reads files, because reading files is a duty
+#pod of C<Dist::Zilla::File::OnDisk> class. Thus, using C<filename> option is critical to provide good
+#pod error messages. Actually, C<fill_in_file> implementation looks like
+#pod
+#pod     $file->content( $self->fill_in_string( $file->content, undef, { filename => $file->name } ) );
+#pod
+#pod There are two problems with the option, though:
+#pod
+#pod =over
+#pod
+#pod =item *
+#pod
+#pod C<Text::Template> does not document this option.
+#pod
+#pod I believe it is a mistake and option should be documented.
+#pod
+#pod =item *
+#pod
+#pod C<Text::Template> ignores this option.
+#pod
+#pod I am sure this is a bug and hope it will be fixed eventually. I am afraid it will not be fixed
+#pod soon, though.
+#pod
+#pod Meanwhile, C<Dist-Zilla-Role-TextTemplater> implements a workaround to let the option work, so C<TextTemplater>
+#pod consumers can utilize the C<filename> option.
+#pod
+#pod =back
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod =for :list
@@ -383,21 +551,23 @@ sub fill_in_string {
 #pod
 #pod     $ dzil build
 #pod     [DZ] beginning to build Assa
-#pod     [COPYING] Can't call method "license" on an undefined value at template line 3.
-#pod     [COPYING] Problem code fragment begins at template line 3.
-#pod     [COPYING] Template text:
+#pod     [COPYING] Can't call method "license" on an undefined value at COPYING line 3.
+#pod     [COPYING] Problem code fragment begins at COPYING line 3.
+#pod     [COPYING] COPYING:
 #pod     [COPYING]     1: This is {{$dist->name}}.
 #pod     [COPYING]     2:
-#pod     [COPYING] >>> 3: {{$dst->license->notice}}
+#pod     [COPYING]     3: {{$dst->license->notice}}
+#pod     [COPYING]        ^^^ Code fragment begins in line above ^^^
+#pod     [COPYING]        ^^^ Code fragment died in line above ^^^
 #pod     Aborting...
 #pod
 #pod See the difference.
 #pod
 #pod =head2 Engine Control
 #pod
-#pod C<TextTemplater> allows the end-user to specify C<package> and C<prepender> engine options from
-#pod F<dist.ini> file, while C<TextTemplate> allows to specify C<prepender> only programmatically, and
-#pod does I<not> allow to specify C<package>.
+#pod C<TextTemplater> allows the end-user to specify C<delimiters>, C<package> and C<prepend> engine
+#pod options in F<dist.ini> file, while C<TextTemplate> allows to specify C<prepend> only
+#pod programmatically, and does I<not> allow to specify C<delimiters> and C<package>.
 #pod
 #pod =cut
 
@@ -418,7 +588,7 @@ Dist::Zilla::Role::TextTemplater - Have text templating capabilities in your Dis
 
 =head1 VERSION
 
-Version 0.003, released on 2015-07-22 12:56 UTC.
+Version 0.004, released on 2015-08-06 16:14 UTC.
 
 =head1 WHAT?
 
@@ -448,13 +618,20 @@ reporting and some others are covered in the L<readme|Dist::Zilla::Role::TextTem
         …
     };
 
+    sub another_method {
+        my $self = shift( @_ );
+        …
+        $self->fill_in_file( $file );
+        …
+    };
+
     __PACKAGE__->meta->make_immutable;
     1;
 
 =head1 DESCRIPTION
 
-The role provides consuming plugin with C<fill_in_string> method and bunch of accompanying
-attributes and F<dist.ini> options.
+The role provides consuming plugin with C<fill_in_string> and C<fill_in_file> methods and bunch of
+accompanying attributes and F<dist.ini> options.
 
 =head1 OBJECT ATTRIBUTES
 
@@ -463,7 +640,7 @@ attributes and F<dist.ini> options.
 Pair of open and closing delimiters the code fragments surrounded by.
 
 Attribute introduces F<dist.ini> option with the same name. Option value will be split on
-whitespaces (and result should ) to initialize the attribute.
+whitespaces (and result should be two words) to initialize the attribute.
 
 C<Str|ArrayRef[Str]>, read-only. Default value is C<[ '{{', '}}' ]>.
 
@@ -478,7 +655,7 @@ Name of package to evaluate code fragments in.
 
 Attribute introduces F<dist.ini> option with the same name.
 
-Str, read-only, optional.
+C<Str>, read-only, optional.
 
 See C<PACKAGE> option of L<Text::Template/"fill_in">.
 
@@ -488,7 +665,7 @@ Perl code to prepend to the beginning of every code fragment.
 
 Attribute introduces F<dist.ini> multi-value option with the same name.
 
-ArrayRef[Str], read-only, auto dereferenced. Default value is empty array. Another default value
+C<ArrayRef[Str]>, read-only, auto dereferenced. Default value is empty array. Another default value
 may be specified by defining C<_build_prepend> method.
 
 See C<PREPEND> option of L<Text::Template/"fill_in">.
@@ -498,11 +675,26 @@ See C<PREPEND> option of L<Text::Template/"fill_in">.
 Callback to execute if a code fragment dies. Default callback formats detailed error message and
 log it by calling C<log_error>.
 
-CodeRef, read-only, not an init argument. Default callback may be overridden by defining
+C<CodeRef>, read-only, not an init argument. Default callback may be overridden by defining
 C<_build_broken> method.
 
 See C<BROKEN> option of L<Text::Template/"fill_in">.
 
+=head2 tt_filename
+
+Name of file being processed, or "template" if no filename was specified (e. g. when processing a
+string and C<filename> option was not specified). Available only during template processing (e. g.
+may be used in a C<broken> subroutine).
+
+C<Str>, read-only, not an init arg.
+
+=head2 tt_template
+
+Template being processed. Available only during template processing (e. g. may be used in a
+C<broken> subroutine).
+
+C<Str>, read-only, not an init arg.
+
 =head1 OBJECT METHODS
 
 =head2 mvp_multivalue_args
@@ -511,24 +703,27 @@ The method tells C<Dist::Zilla> that C<prepend> is a multi-value option.
 
 =head2 fill_in_string
 
-    $result = $self->fill_in_string( $template, \%variables, \%extra_args );
-    $result = $self->fill_in_string( $template );
+    $string = '…';
+    $result = $self->fill_in_string( $string, \%variables, \%extra_args );
+    $result = $self->fill_in_string( $string );
 
 The primary method of the role.
 
 The interface is compatible with method of C<TextTemplate> role, so this role can be used as a
-drop-in replacement for C<TextTemplate>. However, methods are implemented slightly differently
-(this method calls C<Text::Template::fill_in_string> function, that one creates C<Text::Template>
-object first, then calls C<fill_in> method on the object), it may cause subtle difference in
-behaviour.
+drop-in replacement for C<TextTemplate>. However, methods are implemented slightly differently, it
+may cause subtle difference in behaviour.
 
 Template variables C<$plugin> and C<$dist> are set by default, if not explicitly defined in
 C<\%variables>.
 
-The method calls C<Text::Template::fill_in_string>, passing to it the C<$template>, C<\%variables>,
-attribute values C<package>, C<prepend>, C<broken>, and finally C<%extra_args>. C<%extra_args> is
-passed in the end intentionally, so caller may override any of parameters specified by the method,
-for example:
+The method creates C<Text::Template> object, enforces C<Text::Template> to respect C<filename>
+argument (see L<FILENAME parameter has no
+effect|https://rt.cpan.org/Ticket/Display.html?id=106093>), then calls C<fill_in> method on the
+object. C<$template>, C<\%variables>, and C<package>, C<prepend>, C<broken> attribute values, and
+finally C<%extra_args> are passed to the C<fill_in>.
+
+C<%extra_args> is passed in the end intentionally, so caller may override any of arguments
+specified by the method, for example:
 
     $self->fill_in_string( $template, undef, { package => 'MY' } );
         #   Execute code fragments in package MY regardless of $self->package value.
@@ -538,6 +733,16 @@ It also allows to cancel defining C<$plugin> and C<$dist> variables, e. g.:
     $self->fill_in_string( $template, undef, { hash => {} } );
         #   Do not define any variables for the template.
 
+=head2 fill_in_file
+
+    $file = Dist::Zilla::File::OnDisk->new( { … } );
+    $result = $self->fill_in_file( $file, \%variables, \%extra_args );
+    $result = $self->fill_in_file( $file );
+
+Similar to C<fill_in_string>, but the first argument is not a string but a file. File content is
+treated as template, and will be replaced with result of template processing. New file content will
+also be returned.
+
 =head1 NOTES
 
 =head2 C<Text::Template> option spelling
@@ -561,6 +766,54 @@ This feature gives you a choice. If you want to ignore option specified by the u
 and provide your value, use all-lowercase option name. If you want to provide default which can be
 overridden by the user, use all-caps options name.
 
+=head2 C<filename> option
+
+When C<Text::Template> reads template from a file, it uses the file name in error messages, e. g.:
+
+    Undefined subroutine &foo called at filename.ext line n
+
+where I<filename.ext> is the name of file containing the template. When C<Text::Template> processes
+a string, it uses word "template" instead of file name, e. g.:
+
+    Undefined subroutine &foo called at template line n
+
+The option C<filename> allows the caller to override it:
+
+    $self->fill_in_file( $file, undef, { filename => 'Assa.txt' } );
+
+Error message would look like:
+
+    Undefined subroutine &foo called at Assa.txt line n
+
+It may seem this does not make much sense, but in our case (C<Dist::Zilla> and its plugins)
+C<Text::Template> always processes strings and never reads files, because reading files is a duty
+of C<Dist::Zilla::File::OnDisk> class. Thus, using C<filename> option is critical to provide good
+error messages. Actually, C<fill_in_file> implementation looks like
+
+    $file->content( $self->fill_in_string( $file->content, undef, { filename => $file->name } ) );
+
+There are two problems with the option, though:
+
+=over
+
+=item *
+
+C<Text::Template> does not document this option.
+
+I believe it is a mistake and option should be documented.
+
+=item *
+
+C<Text::Template> ignores this option.
+
+I am sure this is a bug and hope it will be fixed eventually. I am afraid it will not be fixed
+soon, though.
+
+Meanwhile, C<Dist-Zilla-Role-TextTemplater> implements a workaround to let the option work, so C<TextTemplater>
+consumers can utilize the C<filename> option.
+
+=back
+
 =head1 WHY?
 
 C<TextTemplate> role from C<Dist::Zilla> distribution v5.037 has the same great C<Text::Template>
@@ -604,21 +857,23 @@ written with C<TextTemplateB<r>> role, result would be:
 
     $ dzil build
     [DZ] beginning to build Assa
-    [COPYING] Can't call method "license" on an undefined value at template line 3.
-    [COPYING] Problem code fragment begins at template line 3.
-    [COPYING] Template text:
+    [COPYING] Can't call method "license" on an undefined value at COPYING line 3.
+    [COPYING] Problem code fragment begins at COPYING line 3.
+    [COPYING] COPYING:
     [COPYING]     1: This is {{$dist->name}}.
     [COPYING]     2:
-    [COPYING] >>> 3: {{$dst->license->notice}}
+    [COPYING]     3: {{$dst->license->notice}}
+    [COPYING]        ^^^ Code fragment begins in line above ^^^
+    [COPYING]        ^^^ Code fragment died in line above ^^^
     Aborting...
 
 See the difference.
 
 =head2 Engine Control
 
-C<TextTemplater> allows the end-user to specify C<package> and C<prepender> engine options from
-F<dist.ini> file, while C<TextTemplate> allows to specify C<prepender> only programmatically, and
-does I<not> allow to specify C<package>.
+C<TextTemplater> allows the end-user to specify C<delimiters>, C<package> and C<prepend> engine
+options in F<dist.ini> file, while C<TextTemplate> allows to specify C<prepend> only
+programmatically, and does I<not> allow to specify C<delimiters> and C<package>.
 
 =head1 SEE ALSO
 
