@@ -81,7 +81,7 @@ before anno => sub {
     my ( $self ) = @_;
     my $in = $self->text;
     diag( "Template:\n" . join( "\n", @$in ) . "\n(end)" );
-    if ( not $self->has_exception ) {
+    if ( not $self->exception ) {
         my $out = $self->tzil->plugin_named( $self->plugin )->text;
         diag( "Output text:\n" . join( "\n", @$out ) . "\n(end)" );
     };
